@@ -1,5 +1,5 @@
 package Geo::Coder::OpenCage;
-$Geo::Coder::OpenCage::VERSION = '0.09';
+$Geo::Coder::OpenCage::VERSION = '0.10';
 use strict;
 use warnings;
 
@@ -26,9 +26,10 @@ sub new {
     return bless $self, $class;
 }
 
-
+# see list: https://geocoder.opencagedata.com/api#forward-opt
 my @valid_params = qw(
     add_request
+    abbrv
     bounds
     countrycode
     language
@@ -116,7 +117,7 @@ Geo::Coder::OpenCage
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -226,9 +227,9 @@ Ed Freyfogle
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2016 OpenCage Data Ltd <cpan@opencagedata.com>
+Copyright 2017 OpenCage Data Ltd <cpan@opencagedata.com>
 
-Please check out all our open source work over at https://github.com/opencagedata and our developer blog: http://blog.opencagedata.com
+Please check out all our open source work over at L<https://github.com/opencagedata> and our developer blog: L<http://blog.opencagedata.com>
 
 Thanks!
 
@@ -242,7 +243,7 @@ edf <edf@opencagedata.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by OpenCage Data Limited.
+This software is copyright (c) 2017 by OpenCage Data Limited.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
